@@ -29,7 +29,7 @@ op_index_min::apply(Mat<uword>& out, const mtOp<uword,T1,op_index_min>& in)
   typedef typename T1::elem_type eT;
   
   const uword dim = in.aux_uword_a;
-  arma_debug_check( (dim > 1), "index_min(): parameter 'dim' must be 0 or 1");
+  arma_debug_check( (dim > 1), "index_min(): parameter 'dim' must be 0 or 1" );
   
   const quasi_unwrap<T1> U(in.m);
   const Mat<eT>& X = U.M;
@@ -88,7 +88,7 @@ op_index_min::apply_noalias(Mat<uword>& out, const Mat<eT>& X, const uword dim)
     
     uword* out_mem = out.memptr();
     
-    Col<T> tmp(X_n_rows);
+    Col<T> tmp(X_n_rows, arma_nozeros_indicator());
     
     T* tmp_mem = tmp.memptr();
     
@@ -195,7 +195,7 @@ op_index_min::apply_noalias(Cube<uword>& out, const Cube<eT>& X, const uword dim
     
     if(out.is_empty() || X.is_empty())  { return; }
     
-    Col<eT> tmp(X_n_rows);
+    Col<eT> tmp(X_n_rows, arma_nozeros_indicator());
     
     eT* tmp_mem = tmp.memptr();
     
@@ -299,7 +299,7 @@ op_index_min::apply_noalias(Cube<uword>& out, const Cube<eT>& X, const uword dim
     
     if(out.is_empty() || X.is_empty())  { return; }
     
-    Col<T> tmp(X_n_rows);
+    Col<T> tmp(X_n_rows, arma_nozeros_indicator());
     
     T* tmp_mem = tmp.memptr();
     
@@ -342,7 +342,7 @@ op_index_min::apply_noalias(Cube<uword>& out, const Cube<eT>& X, const uword dim
     
     uword* out_mem = out.memptr();
     
-    Mat<T> tmp(X_n_rows, X_n_cols);
+    Mat<T> tmp(X_n_rows, X_n_cols, arma_nozeros_indicator());
     
            T*      tmp_mem = tmp.memptr();
     const eT* X_slice0_mem = X.slice_memptr(0);
